@@ -25,6 +25,7 @@
 #include <RcppCommon.h>
 #include <Rcpp/RObject.h>
 #include <Rcpp/Environment.h>
+#include <Rcpp/wrap.h>
 
 namespace Rcpp{ 
 
@@ -32,10 +33,12 @@ class Evaluator{
 public:
     Evaluator(SEXP expression ) ;
     ~Evaluator() ;
-    void run(SEXP env) ;
+    void run(SEXP env) throw() ;
+    void run() throw() ;
     inline RObject getResult() const { return result ; }
     inline RObject getError() const { return error ; }
-	
+    inline bool successfull() const { return !error_occured ; }
+    
 private:		
     SEXP expression ;
     bool error_occured ;
