@@ -461,3 +461,18 @@ RcppExport SEXP RcppVectorExample(SEXP vector) {
 
     return rl;
 }
+
+RcppExport SEXP RcppXPtrExample_create_external_pointer(){
+	std::vector<int> *v = new std::vector<int> ;
+	v->push_back( 1 ) ;
+	v->push_back( 2 ) ;
+	Rcpp::XPtr< std::vector<int> > p(v) ;
+	return p ;
+}
+
+RcppExport SEXP RcppXPtrExample_get_external_pointer(SEXP x){
+	Rcpp::XPtr< std::vector<int> > p(x) ;
+	return Rf_ScalarInteger( p->back( ) ) ;
+}
+
+
